use crate::{
    asset_manager::AssetDefinition,
    sqlite::{Batch, Sqlite},
    AssetManager, Ledger,
};
use sqlx::sqlite::SqlitePoolOptions;

pub async fn get_instance() -> (
    AssetManager,
    Ledger<'static, Batch<'static>, Sqlite<'static>>,
) {
    let pool = SqlitePoolOptions::new()
        .max_connections(1)
        .idle_timeout(None)
        .max_lifetime(None)
        .connect(":memory:")
        //.connect("sqlite:///tmp/test.db")
        .await
        .expect("pool");

    let assets = AssetManager::new(vec![
        AssetDefinition::new(1, "BTC", 8),
        AssetDefinition::new(2, "USD", 4),
    ]);

    let db = Sqlite::new(pool, assets.clone());
    db.setup().await.expect("setup");
    (assets, Ledger::new(db))
}

mod deposit;
